@@ -57,10 +57,7 @@ def handle_superevent(alert):
 
         # run check_vectors. Create and upload omegascans
         group(
-            detchar.omegascan.si(
-                alert['object']['t_0'],
-                superevent_id
-            ).set(countdown=10),
+            detchar.omegascan.si(alert['object']['t_0'], superevent_id),
 
             gracedb.get_event.si(alert['object']['preferred_event'])
             |
@@ -591,6 +588,16 @@ def preliminary_alert(event, superevent_id, annotation_prefix='',
         ) if event['group'] == 'CBC' else identity.s(None)
     )
 
+    # Switch for disabling all but MDC alerts.
+    if app.conf['only_alert_for_mdc']:
+        if event.get('search') != 'MDC':
+            canvas |= gracedb.upload.s(
+                None, None, superevent_id,
+                ("Skipping alert because gwcelery has been configured to only"
+                 " send alerts for MDC events."))
+            canvas.apply_async(priority=priority)
+            return
+
     # Send GCN notice and upload GCN circular draft for online events.
     if is_publishable and initiate_voevent:
         canvas |= (
@@ -598,7 +605,7 @@ def preliminary_alert(event, superevent_id, annotation_prefix='',
             |
             preliminary_initial_update_alert.s(
                 superevent_id,
-                ('earlywarning' if event['search'] == 'EarlyWarning'
+                ('earlywarning' if 'EARLY_WARNING' in event['labels']
                  else 'preliminary'),
                 labels=event['labels'])
         )
@@ -691,6 +698,9 @@ def preliminary_initial_update_alert(filenames, superevent_id, alert_type,
     if filenames is None:
         return
 
+    if 'INJ' in labels:
+        return
+
     skymap_filename, em_bright_filename, p_astro_filename = filenames
     skymap_needed = (skymap_filename is None)
     em_bright_needed = (em_bright_filename is None)
@@ -741,6 +751,8 @@ def preliminary_initial_update_alert(filenames, superevent_id, alert_type,
 
     canvas = (
         group(
+            gracedb.download.si(em_bright_filename, superevent_id),
+            gracedb.download.si(p_astro_filename, superevent_id),
             gracedb.expose.s(superevent_id),
             *(
                 gracedb.create_tag.s(filename, 'public', superevent_id)
@@ -751,11 +763,6 @@ def preliminary_initial_update_alert(filenames, superevent_id, alert_type,
             )
         )
         |
-        group(
-            gracedb.download.si(em_bright_filename, superevent_id),
-            gracedb.download.si(p_astro_filename, superevent_id),
-        )
-        |
         _create_voevent.s(
             superevent_id,
             alert_type,
